const {
  csv,
  select,
  scaleLinear,
  min,
  max,
  extent,
  axisLeft,
  axisBottom,
} = d3;

const width = window.innerWidth;
const height = window.innerHeight;
const margin = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 50,
};
const radius = 5;

const csvUrl = [
  'https://gist.githubusercontent.com/',
  'curran/a08a1080b88344b0c8a7/',
  'raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/',
  'iris.csv',
].join('');

const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const xValue = (d) => d.petal_length;
const yValue = (d) => d.sepal_length;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = (async () => {
  const data = await csv(csvUrl, parseRow);
  console.log(data);

  const x = scaleLinear()
    .domain(
      extent(data, xValue) // [min(data, xValue), max(data, xValue)]
    )
    .range([margin.left, width - margin.right]);

  const y = scaleLinear()
		.domain(extent(data, yValue))
    .range([height - margin.bottom, margin.top]);

  const marks = data.map((d) => ({
    x: x(xValue(d)),
    y: y(yValue(d)),
  }));

  svg
    .selectAll('circle')
    .data(marks)
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', radius);

  svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left}, ${0})`
    )
    .call(axisLeft(y));

  svg
    .append('g')
    .attr(
      'transform',
      `translate(${0}, ${height - margin.bottom})`
    )
    .call(axisBottom(x));
})();
